
namespace IPod {
    
    public enum DeviceModel {
        Invalid,
        Unknown,
        Color,
        ColorU2,
        Regular,
        RegularU2,
        Mini,
        MiniBlue,
        MiniPink,
        MiniGreen,
        MiniGold,
        Shuffle,
        NanoWhite,
        NanoBlack,
        VideoWhite,
        VideoBlack,
        NanoSilver,
        NanoGreen,
        NanoBlue,
        NanoPink,
        NanoProductRed,
        ShuffleSilver,
        ShufflePink,
        ShuffleBlue,
        ShuffleGreen,
        ShuffleOrange
    }
}

